@@ -191,10 +191,16 @@ test_handle_create_success (Test *test,
 {
   GHashTable *request;
   TpAccountChannelRequest *req;
+  TpChannelRequest *chan_req;
 
   request = create_request ();
   req = tp_account_channel_request_new (test->account, request, 0);
 
+  /* We didn't start requesting the channel yet, so there is no
+   * ChannelRequest */
+  chan_req = tp_account_channel_request_get_channel_request (req);
+  g_assert (chan_req == NULL);
+
   tp_account_channel_request_create_and_handle_channel_async (req,
       NULL, create_and_handle_cb, test);
 
@@ -203,6 +209,12 @@ test_handle_create_success (Test *test,
 
   g_main_loop_run (test->mainloop);
   g_assert_no_error (test->error);
+
+  /* The ChannelRequest has been defined */
+  g_object_get (req, "channel-request", &chan_req, NULL);
+  g_assert (TP_IS_CHANNEL_REQUEST (chan_req));
+  g_assert (tp_account_channel_request_get_channel_request (req) == chan_req);
+  g_object_unref (chan_req);
 }
 
 /* ChannelDispatcher.CreateChannel() call fails */
@@ -406,7 +418,6 @@ re_handled_cb (TpAccountChannelRequest *req,
   g_assert_cmpint (timestamp, ==, 666);
   g_assert (TP_IS_HANDLE_CHANNELS_CONTEXT (context));
 
-  g_print ("sig fired\n");
   test->count--;
   if (test->count <= 0)
     g_main_loop_quit (test->mainloop);
@@ -446,6 +457,80 @@ test_handle_re_handle (Test *test,
   g_object_unref (req2);
 }
 
+static void
+create_and_handle_hints_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+
+{
+  Test *test = user_data;
+  TpHandleChannelsContext *context = NULL;
+  GList *reqs;
+  const GHashTable *hints;
+  TpChannelRequest *req;
+
+  test->channel = tp_account_channel_request_create_and_handle_channel_finish (
+      TP_ACCOUNT_CHANNEL_REQUEST (source), result, &context, &test->error);
+  if (test->channel == NULL)
+    goto out;
+
+  g_assert (TP_IS_CHANNEL (test->channel));
+  tp_clear_object (&test->channel);
+
+  g_assert (TP_IS_HANDLE_CHANNELS_CONTEXT (context));
+
+  reqs = tp_handle_channels_context_get_requests (context);
+  g_assert_cmpuint (g_list_length (reqs), ==, 1);
+
+  req = reqs->data;
+  g_assert (TP_IS_CHANNEL_REQUEST (req));
+
+  hints = tp_channel_request_get_hints (req);
+  g_assert_cmpuint (g_hash_table_size ((GHashTable *) hints), ==, 1);
+  g_assert_cmpuint (tp_asv_get_uint32 (hints, "Badger", NULL), ==, 42);
+
+  g_list_foreach (reqs, (GFunc) g_object_unref, NULL);
+  g_list_free (reqs);
+
+  g_object_unref (context);
+
+out:
+  g_main_loop_quit (test->mainloop);
+}
+
+static GHashTable *
+create_hints (void)
+{
+  return tp_asv_new (
+      "Badger", G_TYPE_UINT, 42,
+      NULL);
+}
+
+static void
+test_handle_create_success_hints (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+  GHashTable *hints;
+
+  request = create_request ();
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  hints = create_hints ();
+  tp_account_channel_request_set_hints (req, hints);
+  g_hash_table_unref (hints);
+
+  tp_account_channel_request_create_and_handle_channel_async (req,
+      NULL, create_and_handle_hints_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_no_error (test->error);
+}
+
 /* Request and forget tests */
 
 static void
@@ -640,49 +725,296 @@ test_forget_cancel_after_create (Test *test,
   g_assert_error (test->error, TP_ERRORS, TP_ERROR_CANCELLED);
 }
 
+/* Request and observe tests */
+static void
+create_and_observe_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+
+{
+  Test *test = user_data;
+
+  test->channel = tp_account_channel_request_create_and_observe_channel_finish (
+      TP_ACCOUNT_CHANNEL_REQUEST (source), result, &test->error);
+  if (test->channel == NULL)
+    goto out;
+
+  g_assert (TP_IS_CHANNEL (test->channel));
+  tp_clear_object (&test->channel);
+
+out:
+  g_main_loop_quit (test->mainloop);
+}
+
+static void
+test_observe_create_success (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
+      NULL, create_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_no_error (test->error);
+}
+
+/* ChannelDispatcher.CreateChannel() call fails */
+static void
+test_observe_create_fail (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+
+  /* Ask to the CD to fail */
+  tp_asv_set_boolean (request, "CreateChannelFail", TRUE);
+
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
+      NULL, create_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert (test->channel == NULL);
+}
+
+/* ChannelRequest.Proceed() call fails */
+static void
+test_observe_proceed_fail (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+
+  /* Ask to the CD to fail */
+  tp_asv_set_boolean (request, "ProceedFail", TRUE);
+
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
+      NULL, create_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert (test->channel == NULL);
+}
+
+/* ChannelRequest fire the 'Failed' signal */
+static void
+test_observe_cr_failed (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+
+  /* Ask to the CR to fire the signal */
+  tp_asv_set_boolean (request, "FireFailed", TRUE);
+
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
+      NULL, create_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT);
+  g_assert (test->channel == NULL);
+}
+
+static void
+ensure_and_observe_cb (GObject *source,
+    GAsyncResult *result,
+    gpointer user_data)
+
+{
+  Test *test = user_data;
+
+  test->channel = tp_account_channel_request_ensure_and_observe_channel_finish (
+      TP_ACCOUNT_CHANNEL_REQUEST (source), result, &test->error);
+  if (test->channel == NULL)
+    goto out;
+
+  g_assert (TP_IS_CHANNEL (test->channel));
+  tp_clear_object (&test->channel);
+
+out:
+  g_main_loop_quit (test->mainloop);
+}
+
+static void
+test_observe_ensure_success (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_ensure_and_observe_channel_async (req, "Fake",
+      NULL, ensure_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_no_error (test->error);
+}
+
+/* Cancel the operation before starting it */
+static void
+test_observe_cancel_before (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  g_cancellable_cancel (test->cancellable);
+
+  tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
+      test->cancellable, create_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, G_IO_ERROR, G_IO_ERROR_CANCELLED);
+}
+
+static void
+test_observe_cancel_after_create (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_create_and_observe_channel_async (req, "Fake",
+      test->cancellable, create_and_observe_cb, test);
+
+  g_signal_connect (test->cd_service, "channel-request-created",
+      G_CALLBACK (channel_request_created_cb), test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, TP_ERRORS, TP_ERROR_CANCELLED);
+}
+
+/* Succeeded is fired but not SucceededWithChannel */
+static void
+test_observe_no_channel (Test *test,
+    gconstpointer data G_GNUC_UNUSED)
+{
+  GHashTable *request;
+  TpAccountChannelRequest *req;
+
+  request = create_request ();
+  req = tp_account_channel_request_new (test->account, request, 0);
+
+  tp_account_channel_request_create_and_observe_channel_async (req,
+      "FakeNoChannel", NULL, create_and_observe_cb, test);
+
+  g_hash_table_unref (request);
+  g_object_unref (req);
+
+  g_main_loop_run (test->mainloop);
+  g_assert_error (test->error, TP_ERRORS, TP_ERROR_CONFUSED);
+}
+
 int
 main (int argc,
       char **argv)
 {
   g_type_init ();
+  tp_tests_abort_after (10);
   tp_debug_set_flags ("all");
 
   g_test_init (&argc, &argv, NULL);
   g_test_bug_base ("http://bugs.freedesktop.org/show_bug.cgi?id=");
 
   /* Request and handle tests */
-  g_test_add ("/account-channels-request-handle/create-success", Test, NULL,
+  g_test_add ("/account-channels/request-handle/create-success", Test, NULL,
       setup, test_handle_create_success, teardown);
-  g_test_add ("/account-channels-request-handle/create-fail", Test, NULL,
+  g_test_add ("/account-channels/request-handle/create-fail", Test, NULL,
       setup, test_handle_create_fail, teardown);
-  g_test_add ("/account-channels-request-handle/proceed-fail", Test, NULL,
+  g_test_add ("/account-channels/request-handle/proceed-fail", Test, NULL,
       setup, test_handle_proceed_fail, teardown);
-  g_test_add ("/account-channels-request-handle/cr-failed", Test, NULL,
+  g_test_add ("/account-channels/request-handle/cr-failed", Test, NULL,
       setup, test_handle_cr_failed, teardown);
-  g_test_add ("/account-channels-request-handle/ensure-success", Test, NULL,
+  g_test_add ("/account-channels/request-handle/ensure-success", Test, NULL,
       setup, test_handle_ensure_success, teardown);
-  g_test_add ("/account-channels-request-handle/cancel-before", Test, NULL,
+  g_test_add ("/account-channels/request-handle/cancel-before", Test, NULL,
       setup, test_handle_cancel_before, teardown);
-  g_test_add ("/account-channels-request-handle/after-create", Test, NULL,
+  g_test_add ("/account-channels/request-handle/after-create", Test, NULL,
       setup, test_handle_cancel_after_create, teardown);
-  g_test_add ("/account-channels-request-handle/re-handle", Test, NULL,
+  g_test_add ("/account-channels/request-handle/re-handle", Test, NULL,
       setup, test_handle_re_handle, teardown);
+  g_test_add ("/account-channels/request-handle/create-success-hints", Test,
+      NULL, setup, test_handle_create_success_hints, teardown);
 
-  /* Request and handle tests */
-  g_test_add ("/account-channels-request-forget/create-success", Test, NULL,
+  /* Request and forget tests */
+  g_test_add ("/account-channels/request-forget/create-success", Test, NULL,
       setup, test_forget_create_success, teardown);
-  g_test_add ("/account-channels-request-forget/create-fail", Test, NULL,
+  g_test_add ("/account-channels/request-forget/create-fail", Test, NULL,
       setup, test_forget_create_fail, teardown);
-  g_test_add ("/account-channels-request-foget/proceed-fail", Test, NULL,
+  g_test_add ("/account-channels/request-foget/proceed-fail", Test, NULL,
       setup, test_forget_proceed_fail, teardown);
-  g_test_add ("/account-channels-request-forget/cr-failed", Test, NULL,
+  g_test_add ("/account-channels/request-forget/cr-failed", Test, NULL,
       setup, test_forget_cr_failed, teardown);
-  g_test_add ("/account-channels-request-forget/ensure-success", Test, NULL,
+  g_test_add ("/account-channels/request-forget/ensure-success", Test, NULL,
       setup, test_forget_ensure_success, teardown);
-  g_test_add ("/account-channels-request-forget/cancel-before", Test, NULL,
+  g_test_add ("/account-channels/request-forget/cancel-before", Test, NULL,
       setup, test_forget_cancel_before, teardown);
-  g_test_add ("/account-channels-request-forget/after-create", Test, NULL,
+  g_test_add ("/account-channels/request-forget/after-create", Test, NULL,
       setup, test_forget_cancel_after_create, teardown);
 
+  /* Request and observe tests */
+  g_test_add ("/account-channels/request-observe/create-success", Test, NULL,
+      setup, test_observe_create_success, teardown);
+  g_test_add ("/account-channels/request-observe/create-fail", Test, NULL,
+      setup, test_observe_create_fail, teardown);
+  g_test_add ("/account-channels/request-observe/proceed-fail", Test, NULL,
+      setup, test_observe_proceed_fail, teardown);
+  g_test_add ("/account-channels/request-observe/cr-failed", Test, NULL,
+      setup, test_observe_cr_failed, teardown);
+  g_test_add ("/account-channels/request-observe/ensure-success", Test, NULL,
+      setup, test_observe_ensure_success, teardown);
+  g_test_add ("/account-channels/request-observe/cancel-before", Test, NULL,
+      setup, test_observe_cancel_before, teardown);
+  g_test_add ("/account-channels/request-observe/after-create", Test, NULL,
+      setup, test_observe_cancel_after_create, teardown);
+  g_test_add ("/account-channels/request-observe/no-channel", Test, NULL,
+      setup, test_observe_no_channel, teardown);
+
   return g_test_run ();
 }
